@@ -117,16 +117,17 @@ class PureThriftFormatter(object):
             self.process_node(node)
 
     @staticmethod
-    def _gen_inline_Context(
+    def gen_inline_Context(
             join: str = ' ',
             tight_fn: Optional[Callable[[int, ParseTree], bool]] = None):
-        def fn(self: ThriftFormatter, node: ParseTree):
+        def fn(self: PureThriftFormatter, node: ParseTree):
             for i, child in enumerate(node.children):
                 if i > 0 and len(join) > 0:
                     if not tight_fn or not tight_fn(i, child):
                         self._push(join)
                 self.process_node(child)
         return fn
+    _gen_inline_Context = gen_inline_Context.__func__
 
     def before_subfields_hook(self, _: List[ParseTree]):
         pass
@@ -180,22 +181,10 @@ class PureThriftFormatter(object):
     def DefinitionContext(self, node: ThriftParser.DefinitionContext):
         self.process_node(node.children[0])
 
-    Type_ruleContext = _gen_inline_Context(join='')
-    Enum_fieldContext = _gen_inline_Context(
-        join=' ',
-        tight_fn=lambda _, n: isinstance(n, ThriftParser.List_separatorContext))
-    Field_ruleContext = _gen_inline_Context(join='')
-    Type_idContext = _gen_inline_Context(join='')
-    Type_listContext = _gen_inline_Context(join='')
-    Type_mapContext = _gen_inline_Context(join='')
-    Type_setContext = _gen_inline_Context(join='')
-    Type_baseContext = _gen_inline_Context(join='')
-    Type_identifierContext = _gen_inline_Context(join='')
     Include_Context = _gen_inline_Context()
     Namespace_Context = _gen_inline_Context()
     Typedef_Context = _gen_inline_Context()
     Base_typeContext = _gen_inline_Context()
-    Field_typeContext = _gen_inline_Context()
     Real_base_typeContext = _gen_inline_Context()
     Const_ruleContext = _gen_inline_Context()
     Const_valueContext = _gen_inline_Context()
@@ -209,30 +198,34 @@ class PureThriftFormatter(object):
     List_separatorContext = _gen_inline_Context()
     Field_idContext = _gen_inline_Context(join='')
     Field_reqContext = _gen_inline_Context()
+    Field_typeContext = _gen_inline_Context()
     Map_typeContext = _gen_inline_Context(
-        tight_fn=lambda i, n: not ThriftFormatter._is_token(n.parent.children[i-1], ','))
+        tight_fn=lambda i, n: not PureThriftFormatter._is_token(n.parent.children[i-1], ','))
     Const_listContext = _gen_inline_Context(
         tight_fn=lambda _, n: isinstance(n, ThriftParser.List_separatorContext))
     Enum_ruleContext = _gen_subfields_Context(3, ThriftParser.Enum_fieldContext)
     Struct_Context = _gen_subfields_Context(3, ThriftParser.FieldContext)
     Union_Context = _gen_subfields_Context(3, ThriftParser.FieldContext)
     ExceptionContext = _gen_subfields_Context(3, ThriftParser.FieldContext)
+    Enum_fieldContext = _gen_inline_Context(
+        join=' ',
+        tight_fn=lambda _, n: isinstance(n, ThriftParser.List_separatorContext))
     FieldContext = _gen_inline_Context(
         tight_fn=lambda _, n: isinstance(n, ThriftParser.List_separatorContext))
     Function_Context = _gen_inline_Context(
         tight_fn=lambda i, n:
-            ThriftFormatter._is_token(n, '(') or
-            ThriftFormatter._is_token(n, ')') or
-            ThriftFormatter._is_token(n.parent.children[i-1], '(') or
+            PureThriftFormatter._is_token(n, '(') or
+            PureThriftFormatter._is_token(n, ')') or
+            PureThriftFormatter._is_token(n.parent.children[i-1], '(') or
             isinstance(n, ThriftParser.List_separatorContext)
     )
     OnewayContext = _gen_inline_Context()
     Function_typeContext = _gen_inline_Context()
     Throws_listContext = _gen_inline_Context(
         tight_fn=lambda i, n:
-            ThriftFormatter._is_token(n, '(') or
-            ThriftFormatter._is_token(n, ')') or
-            ThriftFormatter._is_token(n.parent.children[i-1], '(') or
+            PureThriftFormatter._is_token(n, '(') or
+            PureThriftFormatter._is_token(n, ')') or
+            PureThriftFormatter._is_token(n.parent.children[i-1], '(') or
             isinstance(n, ThriftParser.List_separatorContext)
     )
     Type_annotationsContext = _gen_inline_Context()
